#!/usr/bin/python
# -*- coding: UTF-8 -*-


############################################################################
##                                                                        ##
## Zapette                                                                ##
##                                                                        ##
## Copyright (C) 2012  Fabien Loison <flo AT flogisoft DOT com>           ##
##                                                                        ##
## This program is free software: you can redistribute it and/or modify   ##
## it under the terms of the GNU General Public License as published by   ##
## the Free Software Foundation, either version 3 of the License, or      ##
## (at your option) any later version.                                    ##
##                                                                        ##
## This program is distributed in the hope that it will be useful,        ##
## but WITHOUT ANY WARRANTY; without even the implied warranty of         ##
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          ##
## GNU General Public License for more details.                           ##
##                                                                        ##
## You should have received a copy of the GNU General Public License      ##
## along with this program.  If not, see <http://www.gnu.org/licenses/>.  ##
##                                                                        ##
############################################################################


"""Base TV objects."""


class TvProvider(object):
    """Base object for making TV providers."""

    _playlist_url = None
    _channels = []

    def __init__(self):
        """The constructor."""
        self._load_playlist()

    def _load_playlist(self):
        """Load the channel DB from the playlist (should be override)."""
        raise NotImplementedError()

    def get_channel_by_id(self, chan_id):
        """Search a channel with the giver id.

        Returns:
            The channel (TvChannel obj) or None.
        """
        for channel in self:
            if channel.chan_id == chan_id:
                return channel
        return None

    def __iter__(self):
        """Makes this object iterable."""
        for channel in self._channels:
            yield channel


class TvChannel(object):
    """A TV Channel.

    Attributes:
        * chan_id -- The channel's number.
        * name -- The name of the channel.
        * logo -- The file path of the channel logo, or None.
        * streams -- A dict containing all the available streams of the channel.
                     {"HD": "rtsp://domain.tld/stream?q=hd", ...}
    """

    chan_id = -1
    name = ""
    logo = None
    streams = {}

    def __repr__(self):
        """String representation of the object."""
        return "<TvChannel name=\"%s\" id=%i>" % (
                self.name or "Channel %i" % self.chan_id,
                self.chan_id)
